<?php
/**
 * テーマの基本設定フック・エンキュー
 *
 * @package Byakurai
 */

defined( 'ABSPATH' ) || exit;

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function byakurai_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on Byakurai, use a find and replace
		* to change 'byakurai' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'byakurai', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	* Let WordPress manage the document title.
	* By adding theme support, we declare that this theme does not use a
	* hard-coded <title> tag in the document head, and expect WordPress to
	* provide it for us.
	*/
	add_theme_support( 'title-tag' );

	/*
	* Enable support for Post Thumbnails on posts and pages.
	*
	* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	*/
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'menu-1' => esc_html__( 'Primary', 'byakurai' ),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'byakurai_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
	add_theme_support( 'woocommerce' );
	add_theme_support( 'responsive-embeds' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'editor-styles' );
}
add_action( 'after_setup_theme', 'byakurai_setup' );

function byakurai_theme_add_editor_styles() {
	// add_editor_style( 'editor-style.css' );
	add_editor_style( array( 'style.css', 'block-style.css' ) );
}
add_action( 'admin_init', 'byakurai_theme_add_editor_styles' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function byakurai_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'byakurai_content_width', 800 );
}
add_action( 'after_setup_theme', 'byakurai_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function byakurai_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Left Sidebar', 'byakurai' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'byakurai' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Right Sidebar', 'byakurai' ),
			'id'            => 'sidebar-2',
			'description'   => esc_html__( 'Add widgets here.', 'byakurai' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'byakurai_widgets_init' );

/**
 * Enqueue scripts.
 */
function byakurai_scripts() {

	wp_enqueue_script( 'byakurai-navigation', get_template_directory_uri() . '/js/navigation.min.js', array(), BYAKURAI_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'byakurai_scripts' );

/**
 * Enqueue styles.
 */
function byakurai_style() {
	wp_enqueue_style( 'byakurai-style', get_template_directory_uri() . '/style.css', array(), BYAKURAI_VERSION );
	wp_register_style( 'byakurai-block-style', get_template_directory_uri() . '/block-style.css', '', BYAKURAI_VERSION );
	// wp_style_add_data( 'byakurai-style', 'rtl', 'replace' );!
}
add_action( 'wp_enqueue_scripts', 'byakurai_style' );
